@@ -9,4 +9,8 @@ NumericVector round_stochastic_cpp(const NumericVector& x, int digits = 7);
 NumericVector veccrossprod(const NumericMatrix& A, const NumericVector& b);
 NumericVector vecprod(const NumericMatrix& A, const NumericVector& b);
 
+// Internal
+// check is z in contained in X
+bool contains(IntegerVector X, int z);
+
 #endif
